==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSortingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingEventArgsDetailDescriptionMetadata } from "./WebSortingEventArgsDetailDescriptionMetadata";
import { WebSortingEventArgsDescription } from "./WebSortingEventArgsDescription";
/**
 * @hidden
 */
export let WebSortingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingEventArgsDescriptionMetadata.a == null) {
                WebSortingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingEventArgsDescriptionMetadata.c(WebSortingEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebSortingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSortingEventArgsDescriptionMetadata.a);
            WebSortingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebSortingEventArgsDetail");
        }
        static d(a) {
            WebSortingEventArgsDescriptionMetadata.b(a);
            a.aa("WebSortingEventArgs", () => new WebSortingEventArgsDescription());
            a.z("WebSortingEventArgs", WebSortingEventArgsDescriptionMetadata.a);
        }
    }
    WebSortingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingEventArgsDescriptionMetadata, 'WebSortingEventArgsDescriptionMetadata');
    WebSortingEventArgsDescriptionMetadata.a = null;
    return WebSortingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSortingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingEventArgsDetailDescriptionMetadata } from "./WebSortingEventArgsDetailDescriptionMetadata";
import { WebSortingEventArgsDescription } from "./WebSortingEventArgsDescription";
/**
 * @hidden
 */
export let WebSortingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingEventArgsDescriptionMetadata.a == null) {
                WebSortingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingEventArgsDescriptionMetadata.c(WebSortingEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebSortingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSortingEventArgsDescriptionMetadata.a);
            WebSortingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebSortingEventArgsDetail");
        }
        static d(a) {
            WebSortingEventArgsDescriptionMetadata.b(a);
            a.ac("WebSortingEventArgs", () => new WebSortingEventArgsDescription());
            a.ab("WebSortingEventArgs", WebSortingEventArgsDescriptionMetadata.a);
        }
    }
    WebSortingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingEventArgsDescriptionMetadata, 'WebSortingEventArgsDescriptionMetadata');
    WebSortingEventArgsDescriptionMetadata.a = null;
    return WebSortingEventArgsDescriptionMetadata;
})();
